@@ -1,5 +1,11 @@
-// Copyright 2020 ZomboDB, LLC <zombodb@gmail.com>. All rights reserved. Use of this source code is
-// governed by the MIT license that can be found in the LICENSE file.
+/*
+Portions Copyright 2019-2021 ZomboDB, LLC.
+Portions Copyright 2021-2022 Technology Concepts & Design, Inc. <support@tcdi.com>
+
+All rights reserved.
+
+Use of this source code is governed by the MIT license that can be found in the LICENSE file.
+*/
 
 //! Safely create Postgres Background Workers, including with full SPI support
 //!
@@ -63,7 +69,7 @@ impl BackgroundWorker {
     pub fn get_name() -> &'static str {
         #[cfg(feature = "pg10")]
         const LEN: usize = 64;
-        #[cfg(any(feature = "pg11", feature = "pg12", feature = "pg13"))]
+        #[cfg(any(feature = "pg11", feature = "pg12", feature = "pg13", feature = "pg14"))]
         const LEN: usize = 96;
 
         unsafe {
@@ -132,7 +138,7 @@ impl BackgroundWorker {
             #[cfg(feature = "pg10")]
             pg_sys::BackgroundWorkerInitializeConnection(db as *mut c_char, user as *mut c_char);
 
-            #[cfg(any(feature = "pg11", feature = "pg12", feature = "pg13"))]
+            #[cfg(any(feature = "pg11", feature = "pg12", feature = "pg13", feature = "pg14"))]
             pg_sys::BackgroundWorkerInitializeConnection(db, user, 0);
         };
     }
@@ -197,8 +203,6 @@ unsafe extern "C" fn worker_spi_sigterm(_signal_args: i32) {
 /// use pgx::bgworkers::BackgroundWorkerBuilder;
 /// use pgx::*;
 ///
-/// pg_module_magic!();
-///
 /// #[pg_guard]
 /// pub extern "C" fn _PG_init() {
 ///     BackgroundWorkerBuilder::new("My Example BGWorker")
@@ -391,7 +395,7 @@ impl BackgroundWorkerBuilder {
             bgw_notify_pid: self.bgw_notify_pid,
         };
 
-        #[cfg(any(feature = "pg11", feature = "pg12", feature = "pg13"))]
+        #[cfg(any(feature = "pg11", feature = "pg12", feature = "pg13", feature = "pg14"))]
         let mut bgw = pg_sys::BackgroundWorker {
             bgw_name: RpgffiChar::from(&self.bgw_name[..]).0,
             bgw_type: RpgffiChar::from(&self.bgw_type[..]).0,
@@ -438,7 +442,7 @@ fn wait_latch(timeout: i64, wakeup_flags: WLflags) -> i32 {
 #[cfg(feature = "pg10")]
 type RpgffiChar = RpgffiChar64;
 
-#[cfg(any(feature = "pg11", feature = "pg12", feature = "pg13"))]
+#[cfg(any(feature = "pg11", feature = "pg12", feature = "pg13", feature = "pg14"))]
 type RpgffiChar = RpgffiChar96;
 
 struct RpgffiChar64([c_char; 64]);
